<?php 
namespace Concrete\Package\StylishOrderedLists\Block\StylishOrderedLists;

use Concrete\Core\Block\BlockController;
use Loader;

class Controller extends BlockController
{

    protected $btTable = 'btSOL';
    protected $btExportTables = array('btSOL', 'btSOLEntries');
    protected $btInterfaceWidth = "600";
    protected $btWrapperClass = 'ccm-ui';
    protected $btInterfaceHeight = "465";
    protected $btCacheBlockRecord = true;
    protected $btCacheBlockOutput = true;
    protected $btCacheBlockOutputOnPost = true;
    protected $btCacheBlockOutputForRegisteredUsers = true;
	protected $btDefaultSet = 'basic';

    public function getBlockTypeDescription()
    {
        return t("Add beautiful styled ordered lists to your page.");
    }

    public function getBlockTypeName()
    {
        return t("Stylish Ordered Lists");
    }

    public function getSearchableContent()
    {
        $content = '';
        $db = Loader::db();
        $v = array($this->bID);
        $q = 'select * from btSOLEntries where bID = ?';
        $r = $db->query($q, $v);
        foreach ($r as $row) {
            $content .= $row['title'] . ' ' . $row['liContent'];
        }
        return $content;
    }

    public function add()
    {
        $this->requireAsset('core/file-manager');
        $this->requireAsset('core/sitemap');
        $this->requireAsset('redactor');
    }

    public function edit()
    {
        $this->add();

        $db = Loader::db();
        $query = $db->GetAll('SELECT * from btSOLEntries WHERE bID = ? ORDER BY sortOrder', array($this->bID));
        $this->set('rows', $query);
    }

    public function view()
    {
        $db = Loader::db();
        $query = $db->GetAll('SELECT * from btSOLEntries WHERE bID = ? ORDER BY sortOrder', array($this->bID));
        $this->set('rows', $query);
    }

    public function duplicate($newBID)
    {
        $db = Loader::db();
        $v = array($this->bID);
        $q = 'select * from btSOLEntries where bID = ?';
        $r = $db->query($q, $v);
        foreach ($r as $row) {
            $db->execute(
                'INSERT INTO btSOLEntries (bID, title, liContent, sortOrder) values(?,?,?,?)',
                array(
                    $newBID,
                    $row['title'],
                    $row['liContent'],
                    $row['sortOrder']
                )
            );
        }
    }

    public function delete()
    {
        $db = Loader::db();
        $db->execute('DELETE from btSOLEntries WHERE bID = ?', array($this->bID));
        parent::delete();
    }

    public function save($args)
    {
        $db = Loader::db();
		$args['olStyle'] = isset($args['olStyle']) ? trim($args['olStyle']) : 'simple';
		$args['solLiColor'] = isset($args['solLiColor']) ? $args['solLiColor'] : '#333333';
		$args['solLiBgColor'] = $args['solLiBgColor'];
		$args['solLiB4bgColor'] = $args['solLiB4bgColor'];
		$args['solLiContentColor'] = isset($args['solLiContentColor']) ? $args['solLiContentColor'] : '#333333';
		$args['solLiBorderColor'] = $args['solLiBorderColor'];
        $db->execute('DELETE from btSOLEntries WHERE bID = ?', array($this->bID));
        $count = count($args['sortOrder']);
        $i = 0;
        parent::save($args);
        while ($i < $count) {
            $db->execute(
                'INSERT INTO btSOLEntries (bID, title, liContent, sortOrder) values(?,?,?,?)',
                array(
                    $this->bID,
                    $args['title'][$i],
                    $args['liContent'][$i],
                    $args['sortOrder'][$i]
                )
            );
            $i++;
        }
    }

}
